@@ -1,4 +1,4 @@
-#' Create input indicators
+#' @title Create input multipliers
 #' 
 #' The function creates the multipliers (direct + indirect effects).
 #' @param input_requirements A matrix or vector created by 
@@ -7,7 +7,7 @@
 #' @param digits Rounding digits, defaults to \code{NULL}, in which case 
 #' no rounding takes place. Rounding is important if you replicate examples from the literature,
 #' rounding differences can add up to visible differences in matrix equations.
-#' @importFrom dplyr select mutate_at
+#' @importFrom dplyr select mutate across
 #' @importFrom rlang .data
 #' @return A data frame with the vector of multipliers and the an 
 #' auxiliary metadata column (for joining with other matrixes.)
@@ -21,7 +21,7 @@
 #'
 #' compensation_indicator <- input_indicator_create(netherlands_2006, 'compensation_employees')
 #'
-#' I_nl <- leontieff_inverse_create( input_coeff_nl )
+#' I_nl <- leontieff_inverse_create(input_coeff_nl)
 #'
 #' input_multipliers_create(input_requirements = compensation_indicator, 
 #'                         inverse = I_nl)
@@ -34,11 +34,11 @@ input_multipliers_create <- function ( input_requirements,
   names_direct <- names (input_requirements)
   
   new_key_column <- input_requirements %>%
-    dplyr::select (1:2) %>%
-    mutate_at ( vars(1), ~gsub(pattern ="_indicator",
+    select (1:2) %>%
+    mutate(across(1, ~gsub(pattern ="_indicator",
                                           replacement = "", 
-                                          x =.data ) ) %>%
-    mutate_at ( vars(1), ~paste0(.data, "_multiplier"))
+                                          x =.data )) ) %>%
+    mutate(across(1, ~paste0(.data, "_multiplier")))
   
   
   col_n <- ncol(input_requirements)
