@@ -1,10 +1,10 @@
-#' Get An Input-Output Table Fom Bulk File
+#' @title Get an input-output table fom bulk file
 #' 
-#' This function is used to filter out  a single input-output table from
+#' @description This function is used to filter out  a single input-output table from
 #' a database, for example a raw file downloaded from the Eurostat 
 #' website.  It provides some functionality to avoid some pitfalls.
 #' 
-#' Unless you want to work with bulk data files, 
+#' @details Unless you want to work with bulk data files, 
 #' you should not invoke  \code{\link{iotables_download}} 
 #' directly, rather via this function, if and when it is necessary.
 #'  
@@ -55,15 +55,14 @@
 #' The bulk data files on the Eurostat website are in a long form and they are 
 #' not correctly ordered for further matrix equations.
 #' @importFrom magrittr %>%
-#' @importFrom dplyr filter select mutate rename left_join arrange 
-#' @importFrom dplyr mutate_if
-#' @importFrom tidyselect one_of all_of
+#' @importFrom dplyr filter select mutate rename left_join arrange all_of
 #' @importFrom tidyr spread
 #' @importFrom forcats fct_reorder
 #' @importFrom lubridate year
 #' @importFrom utils data
 #' @importFrom rlang .data
-#' @family iotables import functions
+#' @importFrom utils globalVariables
+#' @family import functions
 #' @examples 
 #' germany_table <- iotable_get( source = "germany_1990", 
 #'                  geo = 'DE', year = 1990, unit = "MIO_EUR", 
@@ -79,13 +78,13 @@ iotable_get <- function ( labelled_io_data = NULL,
                           data_directory = NULL, 
                           force_download = TRUE) { 
   
+ 
   ## Initialize NSE variables -----------------------------------------
   #these should be eliminated, but this is a very long code.
   t_cols2  <- t_rows2 <- by_row <- by_col <- NULL
   account_group <- digit_1 <- digit_2 <- group <- quadrant <- NULL
   iotables_row <- iotables_col <- prod_na <- induse <- variable <-  NULL
-  row_order <- col_order <- code <- label <- NULL
-  uk_col <- uk_col_label <- uk_row <- uk_row_label <- indicator <- NULL
+  code <- label <- NULL
 
   if ( labelling == 'eurostat' ) labelling <- 'short'
   ## Parameter exception handling -------------------------------------
@@ -128,14 +127,14 @@ iotable_get <- function ( labelled_io_data = NULL,
   if ( source %in% prod_ind ) { 
     
     metadata_rows <- getdata (metadata) %>%  #tables that follow prod_ind vocabulary
-      dplyr::filter ( variable == "prod_na") %>%
+      filter( variable == "prod_na") %>%
       dplyr::rename ( prod_na = .data$code) %>%
       dplyr::rename ( prod_na_lab = .data$label ) %>%
       dplyr::rename ( row_order = .data$numeric_label ) %>%
       dplyr::rename ( iotables_row = .data$iotables_label )
     
     metadata_cols <- getdata(metadata) %>%
-      dplyr::filter ( variable == "induse") %>%
+      filter( variable == "induse") %>%
       dplyr::rename ( induse = .data$code) %>%
       dplyr::rename ( induse_lab = .data$label )%>%
       dplyr::rename ( col_order = .data$numeric_label ) %>%
@@ -158,14 +157,14 @@ iotable_get <- function ( labelled_io_data = NULL,
     metadata <- getdata(metadata)
     
     metadata_rows <- metadata %>%
-      dplyr::filter ( variable == "t_rows") %>%
+      filter( variable == "t_rows") %>%
       dplyr::rename ( t_rows2 = .data$code) %>%
       dplyr::rename ( t_rows2_lab = .data$label ) %>%
       dplyr::rename ( row_order = .data$numeric_label ) %>%
       dplyr::rename ( iotables_row = .data$iotables_label )
     
     metadata_cols <- metadata %>%
-      dplyr::filter ( variable == "t_cols") %>%
+      filter( variable == "t_cols") %>%
       dplyr::rename ( t_cols2 = .data$code) %>%
       dplyr::rename ( t_cols2_lab = .data$label ) %>%
       dplyr::rename ( col_order = .data$numeric_label ) %>%
@@ -186,8 +185,8 @@ iotable_get <- function ( labelled_io_data = NULL,
       metadata_uk_2010 <- getdata(metadata_uk_2010)
       
       metadata_cols <- metadata_uk_2010  %>%
-        dplyr::filter ( !is.na(.data$uk_col)) %>%
-        dplyr::select ( -uk_row, -uk_row_label, -prod_na, -row_order) %>%
+        filter( !is.na(.data$uk_col)) %>%
+        select( -.data$uk_row, -.data$uk_row_label, -.data$prod_na, -.data$row_order) %>%
         mutate ( uk_col = gsub("\\.", "-", as.character(.data$uk_col))) %>%
         mutate ( uk_col = gsub(" & ", "-", as.character(.data$uk_col))) %>%
         mutate ( uk_col = trimws(.data$uk_col, 'both'))
@@ -203,8 +202,8 @@ iotable_get <- function ( labelled_io_data = NULL,
     stop ("This type of input-output database is not (yet) recognized by iotables.")
   }
   
-  metadata_rows <- mutate_if ( metadata_rows, is.factor, as.character )
-  metadata_cols <- mutate_if ( metadata_cols, is.factor, as.character )
+  metadata_rows <- metadata_rows %>% mutate ( across(where(is.factor), as.character) )
+  metadata_cols <- metadata_cols %>% mutate ( across(where(is.factor), as.character) )
   
   ###Exception handling for wrong paramters that are not directly inputed-----
   if ( is.null(labelled_io_data) ) {  #if not directly inputed data 
@@ -267,27 +266,27 @@ iotable_get <- function ( labelled_io_data = NULL,
   if ( source %in% uk_tables ) {
     if ( source == "uk_2010_siot") {
       labelled_io_data <- labelled_io_data %>%
-        dplyr::filter ( .data$indicator == 'Input-Output table (domestic use, basic prices, product by product)')
+        filter( .data$indicator == 'Input-Output table (domestic use, basic prices, product by product)')
     }
     
     if ( source == "uk_2010_use") {
       labelled_io_data <- labelled_io_data %>%
-        dplyr::filter ( .data$indicator == 'Domestic use table at basic prices (product by industry)')
+        filter( .data$indicator == 'Domestic use table at basic prices (product by industry)')
     }
     
     if ( source == "uk_2010_imports") {
       labelled_io_data <- labelled_io_data %>%
-        dplyr::filter ( .data$indicator == 'Imports use table at basic prices (product by product)')
+        filter( .data$indicator == 'Imports use table at basic prices (product by product)')
     }
     
     if ( source == "uk_2010_coeff") {
       labelled_io_data <- labelled_io_data %>%
-        dplyr::filter ( .data$indicator == 'Matrix of coefficients (product by product)')
+        filter( .data$indicator == 'Matrix of coefficients (product by product)')
     }
     
     if ( source == "uk_2010_inverse") {
       labelled_io_data <- labelled_io_data %>%
-        dplyr::filter ( .data$indicator == 'Leontief Inverse (product by product)')
+        filter( .data$indicator == 'Leontief Inverse (product by product)')
     }
   } 
    
@@ -367,30 +366,30 @@ iotable_get <- function ( labelled_io_data = NULL,
   remove_vars  <- remove_vars [remove_vars %in% names (metadata_cols)]
   
   iotable_labelled <- iotable %>%
-    dplyr::filter (stk_flow == stk_flow_input )  %>%
-    dplyr::mutate_if ( is.factor, as.character ) %>%
-    dplyr::left_join ( metadata_cols, by = col_join  ) %>%
-    dplyr::select ( -one_of(remove_vars) ) %>%  #remove repeating columns before joining rows
-    dplyr::mutate_if ( is.factor, as.character ) %>% 
-    dplyr::left_join ( metadata_rows, by = row_join ) 
+    filter(stk_flow == stk_flow_input )  %>%
+    mutate( across(where(is.factor), as.character) ) %>%
+    left_join( metadata_cols, by = col_join  ) %>%
+    select( -all_of(remove_vars) ) %>%  #remove repeating columns before joining rows
+    mutate( across(where(is.factor), as.character) ) %>% 
+    left_join ( metadata_rows, by = row_join ) 
     
     if ( nrow (iotable_labelled) == 0 ) {
       stop ( "No rows found with geo = ", geo_input, " year = ", year, 
              " unit = ", unit, " and stk_flow = ", stk_flow_input, "." )
     }
   
-    iotable_labelled <- iotable_labelled %>%
-      dplyr::mutate ( prod_na = forcats::fct_reorder(prod_na, 
-                                              as.numeric(row_order))) %>%
-      dplyr::mutate ( induse  = forcats::fct_reorder(induse, 
-                                             as.numeric(col_order))) 
-    
+  iotable_labelled <- iotable_labelled %>%
+    mutate(prod_na = forcats::fct_reorder(prod_na, 
+                                          as.numeric(.data$row_order))) %>%
+    mutate(induse  = forcats::fct_reorder(induse, 
+                                          as.numeric(.data$col_order))) 
+  
     if ( all(c("iotables_row", "iotables_col") %in%  names (iotable_labelled)) ) {
       iotable_labelled <-  iotable_labelled %>%
-        dplyr::mutate ( iotables_row = forcats::fct_reorder(iotables_row ,
-                                                            as.numeric(row_order))) %>%
-        dplyr::mutate ( iotables_col = forcats::fct_reorder(iotables_col, 
-                                                            as.numeric(col_order)))
+        mutate(iotables_row = forcats::fct_reorder(iotables_row ,
+                                                   as.numeric(.data$row_order))) %>%
+        mutate(iotables_col = forcats::fct_reorder(iotables_col, 
+                                                   as.numeric(.data$col_order)))
     }
    
   } else  {
@@ -400,41 +399,41 @@ iotable_get <- function ( labelled_io_data = NULL,
       by_row <- names(iotable)[which ( names(iotable) %in% c("t_rows2", "t_rows2_lab", "iotables_row") )]
       
       iotable_labelled <- iotable %>%
-        mutate_if ( is.factor, as.character ) %>%
-        left_join ( metadata_cols, by = by_col )  %>%
-        left_join ( metadata_rows, by = by_row ) %>%
-        arrange ( row_order, col_order )
+        mutate ( across(where(is.factor), as.character) ) %>%
+        left_join(metadata_cols, by = by_col)  %>%
+        left_join(metadata_rows, by = by_row) %>%
+        arrange ( .data$row_order, .data$col_order )
     } else {
       iotable_labelled <- iotable 
     }
     iotable_labelled <- iotable_labelled %>%
-      dplyr::mutate ( t_rows2 = forcats::fct_reorder(t_rows2, 
-                                              as.numeric( row_order))) %>%
-      dplyr::mutate ( t_cols2 = forcats::fct_reorder(t_cols2, 
-                                              as.numeric( col_order ))) %>%
-      dplyr::mutate ( iotables_row = forcats::fct_reorder(iotables_row , 
-                                                       as.numeric(row_order))) %>%
-      dplyr::mutate ( iotables_col = forcats::fct_reorder(iotables_col, 
-                                                         as.numeric( col_order)))
+      mutate(t_rows2 = forcats::fct_reorder(t_rows2, 
+                                            as.numeric(.data$row_order))) %>%
+      mutate(t_cols2 = forcats::fct_reorder(t_cols2, 
+                                            as.numeric( .data$col_order ))) %>%
+      mutate(iotables_row = forcats::fct_reorder(iotables_row, 
+                                                 as.numeric(.data$row_order))) %>%
+      mutate(iotables_col = forcats::fct_reorder(iotables_col, 
+                                                 as.numeric(.data$col_order)))
   } #end of not prod_na cases
 
   if ( labelling == "iotables" ) {
     
     iotable_labelled_w <- iotable_labelled %>%
-      dplyr::arrange (iotables_row, iotables_col) %>%
-      dplyr::select ( all_of(c("iotables_col", "iotables_row", "values")) ) %>% 
+      arrange (iotables_row, iotables_col) %>%
+      select( all_of(c("iotables_col", "iotables_row", "values")) ) %>% 
       tidyr::spread (iotables_col, .data$values)
     
   } else if ( labelling == "short" & source %in% prod_ind ) {
     
     iotable_labelled_w <- iotable_labelled %>%
-      dplyr::select (.data$prod_na, .data$induse, .data$values) %>%
-      dplyr::filter ( !is.na(.data$prod_na) )  %>%
+      select(.data$prod_na, .data$induse, .data$values) %>%
+      filter( !is.na(.data$prod_na) )  %>%
       tidyr::spread (induse, .data$values )
 
   } else {
     iotable_labelled_w <- iotable_labelled %>%
-      dplyr::select ( all_of(c("t_rows2", "t_cols2", "values")) ) %>%
+      select( all_of(c("t_rows2", "t_cols2", "values")) ) %>%
       tidyr::spread ( t_cols2, .data$values )
   }
   
